import pandas as pd
import numpy as np
import warnings
import lhcsmapi
from lhcsmapi.Time import Time
from lhcsmapi.analysis.CircuitQuery import CircuitQuery


class _600ACircuitQuery(CircuitQuery):

    def create_report_analysis_template(self, timestamp_fgc, author=''):
        columns = ['Circuit Name', 'Family', 'Period', 'Date', 'Time', 'flagged in APEX', 'Quench Current',
                   'I_MEAS MIITs', 'Reason', 'Pivot', 'Quench Origin',
                   'Ramp Rate', 'Plateau Duration', 'dUres/dt', 'EE max voltage', 'Earth Current', 'Coupling',
                   'Comment', 'performed_by', 'Reference Doc', 'lhcsmapi_version']
        results_table = pd.DataFrame(columns=columns, index=[0])

        results_table['Circuit Name'] = self.circuit_name
        results_table['Family'] = self.circuit_name.split('.')[0]
        results_table['Date'] = Time.to_string_short(timestamp_fgc).split(' ')[0]
        results_table['Time'] = Time.to_string_short(timestamp_fgc).split(' ')[1]
        results_table['performed_by'] = author

        results_table['lhcsmapi_version'] = lhcsmapi.__version__

        return results_table

    def create_report_analysis_template_rcd(self, timestamp_fgc_rcd, timestamp_fgc_rco, circuit_names, author):
        columns = ['Circuit Name', 'Family', 'Period', 'Date', 'Time', 'flagged in APEX', 'I_Q_RCD', 'I_Q_RCO',
                   'I_MEAS MIITs RCD', 'I_MEAS MIITs RCO', 'Reason', 'Quench Origin', 'Ramp Rate RCD', 'Ramp Rate RCO',
                   'Plateau Duration', 'dUres/dt RCD', 'dUres/dt RCO', 'Comment', 'Person who analyzed',
                   'Reference Doc']
        results_table = pd.DataFrame(columns=columns, index=[0])

        results_table['Family'] = 'RCD'
        timestamp_fgc = min(timestamp_fgc_rcd, timestamp_fgc_rco)
        if not np.isnan(timestamp_fgc):
            results_table['Date'] = Time.to_string_short(timestamp_fgc).split(' ')[0]
            results_table['Time'] = Time.to_string_short(timestamp_fgc).split(' ')[1]

        if not np.isnan(timestamp_fgc_rcd) and not np.isnan(timestamp_fgc_rco):
            results_table['Circuit Name'] = circuit_names[0].replace('RCD', 'RCD/O')
        elif not np.isnan(timestamp_fgc_rcd):
            results_table['Circuit Name'] = circuit_names[0]
        elif not np.isnan(timestamp_fgc_rco):
            results_table['Circuit Name'] = circuit_names[1]
        else:
            warnings.warn('Both RCD and RCO FGC timestamps are missing.')

            results_table['performed_by'] = author
            results_table['lhcsmapi_version'] = lhcsmapi.__version__

        return results_table
